@@ -1,4 +1,4 @@
-# Copyright (c) 2025 Löwenfelsen UG (haftungsbeschränkt)
+# Copyright (c) 2025 Philipp Schafft
 
 # licensed under Artistic License 2.0 (see LICENSE file)
 
@@ -21,7 +21,7 @@ use User::Information::Source;
 
 use Carp;
 
-our $VERSION = v0.04;
+our $VERSION = v0.05;
 
 use constant {
     PATH_LOCAL_SYSAPI   => User::Information::Path->new([qw(local sysapi)]),
@@ -342,7 +342,7 @@ User::Information::Base - generic module for extracting information from user ac
 
 =head1 VERSION
 
-version v0.04
+version v0.05
 
 =head1 SYNOPSIS
 
@@ -483,11 +483,11 @@ Whether or not L<perlfunc/binmode> is called on the newly open file handle. Defa
 
 =head1 AUTHOR
 
-Löwenfelsen UG (haftungsbeschränkt) <support@loewenfelsen.net>
+Philipp Schafft <lion@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2025 by Löwenfelsen UG (haftungsbeschränkt) <support@loewenfelsen.net>.
+This software is Copyright (c) 2025 by Philipp Schafft <lion@cpan.org>.
 
 This is free software, licensed under:
 
