@@ -16,7 +16,7 @@ use File::Spec;
 
 use User::Information::Path;
 
-our $VERSION = v0.04;
+our $VERSION = v0.05;
 
 # ---- Private helpers ----
 
@@ -55,7 +55,7 @@ User::Information::Source::VFS - generic module for extracting information from
 
 =head1 VERSION
 
-version v0.04
+version v0.05
 
 =head1 SYNOPSIS
 
@@ -65,11 +65,11 @@ This is a provider for filesystem configuration.
 
 =head1 AUTHOR
 
-Löwenfelsen UG (haftungsbeschränkt) <support@loewenfelsen.net>
+Philipp Schafft <lion@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2025 by Löwenfelsen UG (haftungsbeschränkt) <support@loewenfelsen.net>.
+This software is Copyright (c) 2025 by Philipp Schafft <lion@cpan.org>.
 
 This is free software, licensed under:
 
