@@ -19,7 +19,7 @@ use User::Information::Path;
 
 use constant PATH_HOMEDIR => User::Information::Path->new(['aggregate', 'homedir']);
 
-our $VERSION = v0.04;
+our $VERSION = v0.05;
 
 my @_homedir_keys = qw(home desktop documents music pictures videos data);
 
@@ -136,7 +136,7 @@ User::Information::Source::XDG - generic module for extracting information from
 
 =head1 VERSION
 
-version v0.04
+version v0.05
 
 =head1 SYNOPSIS
 
@@ -146,11 +146,11 @@ This is a provider for filesystem configuration using the XDG standards.
 
 =head1 AUTHOR
 
-Löwenfelsen UG (haftungsbeschränkt) <support@loewenfelsen.net>
+Philipp Schafft <lion@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2025 by Löwenfelsen UG (haftungsbeschränkt) <support@loewenfelsen.net>.
+This software is Copyright (c) 2025 by Philipp Schafft <lion@cpan.org>.
 
 This is free software, licensed under:
 
